# Generated by Django 3.0.2 on 2020-01-10 23:18

from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
    ]

    operations = [
        migrations.CreateModel(
            name='VimeoClientOption',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False, verbose_name='ID')),
                ('vimeo_user_id', models.CharField(default='', max_length=100, verbose_name='Vimeo User ID')),
                ('vimeo_client_id', models.CharField(default='', max_length=100, verbose_name='Vimeo Client ID')),
                ('vimeo_client_secret', models.CharField(default='', max_length=100, verbose_name='Vimeo Client Secret')),
                ('vimeo_access_token', models.CharField(default='', max_length=100, verbose_name='Vimeo Access Token')),
                ('vimeo_project_id', models.CharField(default='', max_length=100, unique=True, verbose_name='Vimeo Project ID/Folder ID')),
                ('site', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='sites.Site', verbose_name='Site')),
            ],
            options={
                'verbose_name': 'CPSS Vimeo Client Setting',
                'verbose_name_plural': 'CPSS Vimeo Client Settings',
                'db_table': 'vimeo_django_settings',
            },
        ),
    ]
